summaryrefslogtreecommitdiff
path: root/src/lib/encoder.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2014-05-14 11:27:17 +0100
committerCarl Hetherington <cth@carlh.net>2014-05-14 11:27:17 +0100
commit5c09a82e483593fb37da0cad20679be735887613 (patch)
tree9fb0540536514aa1dc7d4fd4c056c24ca52f59d3 /src/lib/encoder.h
parent8f7d0cf115980cb357bc3da410842503930e66b8 (diff)
Move Eyes and ColourConversion into PlayerVideoFrame.
Diffstat (limited to 'src/lib/encoder.h')
-rw-r--r--src/lib/encoder.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/encoder.h b/src/lib/encoder.h
index 5cdda459d..a8ee220aa 100644
--- a/src/lib/encoder.h
+++ b/src/lib/encoder.h
@@ -67,10 +67,10 @@ public:
void process_begin ();
/** Call with a frame of video.
* @param i Video frame image.
* @param same true if i is the same as the last time we were called.
*/
- void process_video (boost::shared_ptr<PlayerVideoFrame> i, Eyes eyes, ColourConversion, bool same);
+ void process_video (boost::shared_ptr<PlayerVideoFrame> pvf, bool same);
/** Call with some audio data */
void process_audio (boost::shared_ptr<const AudioBuffers>);
@@ -67,10 +67,10 @@ public:
void process_begin ();
/** Call with a frame of video.
- * @param i Video frame image.
- * @param same true if i is the same as the last time we were called.
+ * @param pvf Video frame image.
+ * @param same true if pvf is the same as the last time we were called.
*/